# Python-Image-Fetcher (image_fetcher)
https://github.com/BenAAndrew/Python-Image-Fetcher


**A simple lightweight library to download images from google.**


# [Documentation](https://python-image-fetcher.readthedocs.io/ "Python Image Fetcher")
